#
# spec file for package SHERPA-MC
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname lib%{name}0

Name:           SHERPA-MC
Version:        2.2.3
Release:        1.2
Summary:        MC event generator for Simulation of High-Energy Reactions of PArticles
License:        GPL-2.0+ and GPL-3.0
Group:          Development/Libraries/C and C++
Url:            https://sherpa.hepforge.org/
Source:         http://www.hepforge.org/archive/sherpa/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM SHERPA-MC-no-return-in-non-void-function.patch badshah400@gmail.com -- Fix a non-void (bool) function that was not returning any data to return "true"
Patch0:         SHERPA-MC-no-return-in-non-void-function.patch
BuildRequires:  HepMC-devel
BuildRequires:  LHAPDF-devel
BuildRequires:  Rivet-devel
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  fastjet-devel
BuildRequires:  fastjet-plugin-siscone-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  openmpi-devel
BuildRequires:  pkg-config
BuildRequires:  pythia-devel
BuildRequires:  python-devel
BuildRequires:  sqlite3-devel
BuildRequires:  swig
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(yaml-cpp)
BuildRequires:  pkgconfig(zlib)
Requires(post):  info
Requires(preun): info

%description
Sherpa is a Monte Carlo event generator for the Simulation of
High-Energy Reactions of PArticles in lepton-lepton, lepton-photon,
photon-photon, lepton-hadron and hadron-hadron collisions. It provides
complete hadronic final states in simulations of high-energy particle
collisions. The produced events may be passed into detector
simulations used by the various experiments. The entire code has been
written in C++.

Sherpa simulations can be achieved for the following types of
collisions:
 - For lepton–lepton collisions, as explored by the CERN LEP
   experiments,
 - for lepton–photon collisions,
 - for photon–photon collisions with both photons either resolved or
   unresolved,
 - for deep-inelastic lepton-hadron scattering, as investigated by
   the HERA experiments at DESY, and,
 - in particular, for hadronic interactions as studied at the
   Fermilab Tevatron or the CERN LHC.

%package -n %soname
Summary:        MC event generator for Simulation of High-Energy Reactions of PArticles
Group:          System/Libraries
Obsoletes:      libSHERPA-MC < %version-%release
Provides:       libSHERPA-MC = %version-%release
Requires:       libSHERPA-MC-config

%description -n %soname
Sherpa is a Monte Carlo event generator for the Simulation of
High-Energy Reactions of PArticles in lepton-lepton, lepton-photon,
photon-photon, lepton-hadron and hadron-hadron collisions. It provides
complete hadronic final states in simulations of high-energy particle
collisions. The produced events may be passed into detector
simulations used by the various experiments. The entire code has been
written in C++.

This package provides the shared libraries for Sherpa.

%package -n libSHERPA-MC-config
Summary:        Dynamic linker configuration for the SHERPA-MC libraries
Group:          System/Base
BuildArch:      noarch

%description -n libSHERPA-MC-config
Contains the ld.so.conf.d file for the SHERPA-MC libraries.

%package devel
Summary:        MC event generator for Simulation of High-Energy Reactions of PArticles
Group:          Development/Libraries/C and C++
Requires:       %soname = %{version}

%description devel
Sherpa is a Monte Carlo event generator for the Simulation of
High-Energy Reactions of PArticles in lepton-lepton, lepton-photon,
photon-photon, lepton-hadron and hadron-hadron collisions. It provides
complete hadronic final states in simulations of high-energy particle
collisions. The produced events may be passed into detector
simulations used by the various experiments. The entire code has been
written in C++.

This package provides the source and header files for development with
Sherpa.

%package -n python-%{name}
Summary:        Python extensions for SHERPA-MC
Group:          Development/Languages/Python

%description -n python-%{name}
Sherpa is a Monte Carlo event generator for the Simulation of
High-Energy Reactions of PArticles in lepton-lepton, lepton-photon,
photon-photon, lepton-hadron and hadron-hadron collisions. It provides
complete hadronic final states in simulations of high-energy particle
collisions. The produced events may be passed into detector
simulations used by the various experiments. The entire code has been
written in C++.

This package provides the python extensions for Sherpa.

%prep
%setup -q
%patch0 -p1

%build
%configure \
  --libdir=%{_libdir}  \
  --docdir=%{_docdir}/%{name}  \
  --enable-pyext       \
  --enable-analysis    \
  --enable-multithread \
  --enable-gzip        \
  --enable-hepmc2=%{_prefix}      \
  --enable-fastjet=%{_prefix}     \
  --enable-lhapdf=%{_prefix}      \
  --enable-pythia=%{_prefix}

# FIXME: Disable rivet bindings until SHERPA-MC builds with latest Rivet >= 2.1.2
#  --enable-rivet=%%{_prefix}       \

make %{?_smp_mflags}

%install
%make_install

mkdir -p %{buildroot}/%{_sysconfdir}/ld.so.conf.d
echo %{_libdir}/%{name} > %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}.conf

find %{buildroot}%{_libdir}/%{name}/ -name *.la -delete

%fdupes %{buildroot}%{_datadir}/%{name}/
%fdupes %{buildroot}%{python_sitelib}/

%post -n %soname -p /sbin/ldconfig

%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/Sherpa.*.gz

%postun -n %soname -p /sbin/ldconfig

%preun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/Sherpa.*.gz

%files -n %soname
%defattr(-,root,root)
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/*.so.*

%files -n libSHERPA-MC-config
%defattr(-,root,root)
%config %{_sysconfdir}/ld.so.conf.d/%{name}.conf

%files devel
%defattr(-,root,root)
%doc ChangeLog README COPYING
%{_bindir}/get_bibtex
%{_bindir}/Combine_Analysis
%{_bindir}/Sherpa
%{_bindir}/Sherpa-config
%{_bindir}/init_nlo.sh
%{_bindir}/make2scons
%{_bindir}/plot_graphs.sh
%{_bindir}/plot_stats.sh
%dir %{_docdir}/%{name}/
%{_docdir}/%{name}/*.html
%{_docdir}/%{name}/*.jpg
%{_libdir}/%{name}/*.so
%{_includedir}/%{name}/
%{_datadir}/%{name}/
%{_mandir}/man1/Sherpa.*.gz
%{_infodir}/Sherpa.*.gz

%files -n python-%{name}
%defattr(-,root,root)
%{python_sitelib}/Sherpa.py*
%{python_sitelib}/_Sherpa.*

%changelog
* Fri Apr 28 2017 badshah400@gmail.com
- Update to version 2.2.3:
  * Support for the Recola one-loop generator for QCD corrections.
- Add SHERPA-MC-no-return-in-non-void-function.patch -- Fix a
  non-void (bool) function that was not returning any data to
  return "true".
* Mon Feb 13 2017 jengelh@inai.de
- Shared library package must only contain time-unique names;
  split off libSHERPA-MC-config.
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Nov 10 2016 badshah400@gmail.com
- Update to version 2.2.1:
  * Incoporation of approximate NLO EW corrections in MEPS@NLO
    simulation as described in arXiv:1511.08692
  * On-the-fly renormalisation and factorisation scale, PDF and
    alpha_s variations in the matrix elements for LO, LOPS, NLOPS,
    MEPS, MENLOPS and MEPS@NLO simulations as described in
    arXiv:1606.08753
- Changes from version 2.2.0: See
  https://sherpa.hepforge.org/trac/wiki/SherpaDownloads/Sherpa-2.2.0.
- Drop gcc6_char_cast.patch; incorporated upstream.
* Sun Jun 19 2016 jengelh@inai.de
- RPM group classification
- run install_info in preun to avoid errors of missing files
- Shared library subpackage is supposed to include the number
* Thu Jun 16 2016 normand@linux.vnet.ibm.com
-  new gcc6_char_cast.patch
* Mon Jun 23 2014 badshah400@gmail.com
- License tag in spefile corrected, should be GPL-2.0+ and
  GPL-3.0.
* Sun Jun 22 2014 badshah400@gmail.com
- Update to version 2.1.1 (Bug-fix release):
  + A bug related to MC@NLO has been fixed. This will affect the
    total cross section in heavy quark production at the level of
    few permille.
  + A bug related to parton showering in associated Higgs boson
    production has been fixed.
  + A problem related to SQLite database locking on IBM BG/Q
    systems has been solved.
  + A bug related to CS subtraction with Comix has been fixed.
    This will eliminate possible large weights in events
    containing extremely soft gluons.
  + A bug related to the QED corrections on the hard interaction
    accidentally being switched off has been fixed.
  + A bug related to the contents of the HepMC::PdfInfo? object
    in MC@NLO event generation has been fixed.
  + A bug in the underlying event simulation, presenting as a final
    state particle asymmetry, has been fixed. An update of the
    underlying event parameters was necessary, invalidating MPI
    grids generated with previous versions.
  + The Python interface to access Sherpa's matrix elements has
    been updated and supplemented with a C++ interface.
  + A bug in the CS subtraction in DRED has been fixed.
- Changes from version 2.1.0:
  + Introduced SQLite as the preferred storage manager
  + Spin correlated decay chains (Comix only), includes all 1->2
    and 1->3 decays allowed by the model, iterated to arbitrary
    decay chain length, all decay steps are dressed with QCD
    parton showers and QED corrections
  + MC@NLO H events with Comix, speeds up initialisation and
    runtime
- Packaging changes:
  + Disable rivet bindings until SHERPA-MC builds with latest
    Rivet >= 2.1.2
  + BuildRequires on sqlite3-devel introduced since version 2.1.0
  + Package new binaries init_nlo.sh, make2scons, plot_graphs.sh.
* Mon Dec 16 2013 badshah400@gmail.com
- Initial version.
